camelot.camelot.view.application_admin.ApplicationAdmin

Package camelot :: Package camelot :: Package view :: Module application_admin :: Class ApplicationAdmin |
[hide private]
[frames] | no frames]

# Class ApplicationAdmin

source code

Instance Methods | [hide private]
__init__(self, main_sections) The main sections to be used in the navigation pane of the application, all entities will be put in such a section, depending on the properties of their EntityAdmin class, a list of tuples of strings and icons [('section', ('Section display name',section_icon))] | source code
register(self, entity, admin_class) | source code
getSections(self) | source code
getEntityAdmin(self, entity) Get the default entity admin for this entity, return None, if not existant | source code
getEntityQuery(self, entity) Get the root query for an entity | source code
getEntitiesAndQueriesInSection(self, section) Returns: a list of tuples of (admin, query) instances related to the entities in this section. | source code
getActions(self) Returns: a list of actions that should be added to the menu and the icon bar for this application, each action is a tuple of (name, icon, callable), where callable is a function taking no arguments that will be called when the action is executed. | source code
getName(self) Returns: the name of the application | source code
getIcon(self) | source code
getAbout(self) Returns: the content of the About dialog | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| sections = ``[``]``
| admins = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, main_sections) (Constructor) | source code
The main sections to be used in the navigation pane of the application, all entities will be put in such a section, depending on the properties of their EntityAdmin class, a list of tuples of strings and icons [('section', ('Section display name',section_icon))] Overrides: object.__init__

### getEntitiesAndQueriesInSection(self, section) | source code
Returns: a list of tuples of (admin, query) instances related to the entities in this section.

### getActions(self) | source code
Returns: a list of actions that should be added to the menu and the icon bar for this application, each action is a tuple of (name, icon, callable), where callable is a function taking no arguments that will be called when the action is executed. Callable will be called in the model thread.

### getName(self) | source code
Returns: the name of the application

### getAbout(self) | source code
Returns: the content of the About dialog